/*
 *  Copyright 2007-2013, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */

@javax.xml.bind.annotation.XmlSchema(namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", xmlns = {
    @javax.xml.bind.annotation.XmlNs(prefix = "mc", namespaceURI = "http://schemas.openxmlformats.org/markup-compatibility/2006") },
elementFormDefault = javax.xml.bind.annotation.XmlNsForm.QUALIFIED)

package org.docx4j.wml;
